@@ -34,48 +34,6 @@ require_once($CFG->libdir.'/outputfactories.php');
 require_once($CFG->libdir.'/outputrenderers.php');
 require_once($CFG->libdir.'/outputrequirementslib.php');
 
-/**
- * Invalidate all server and client side caches.
- *
- * This method deletes the physical directory that is used to cache the theme
- * files used for serving.
- * Because it deletes the main theme cache directory all themes are reset by
- * this function.
- */
-function theme_reset_all_caches() {
-    global $CFG, $PAGE;
-
-    $next = time();
-    if (isset($CFG->themerev) and $next <= $CFG->themerev and $CFG->themerev - $next < 60*60) {
-        // This resolves problems when reset is requested repeatedly within 1s,
-        // the < 1h condition prevents accidental switching to future dates
-        // because we might not recover from it.
-        $next = $CFG->themerev+1;
-    }
-
-    set_config('themerev', $next); // time is unique even when you reset/switch database
-
-    if (!empty($CFG->themedesignermode)) {
-        $cache = cache::make_from_params(cache_store::MODE_APPLICATION, 'core', 'themedesigner');
-        $cache->purge();
-    }
-
-    if ($PAGE) {
-        $PAGE->reload_theme();
-    }
-}
-
-/**
- * Enable or disable theme designer mode.
- *
- * @param bool $state
- */
-function theme_set_designer_mod($state) {
-    set_config('themedesignermode', (int)!empty($state));
-    // Reset caches after switching mode so that any designer mode caches get purged too.
-    theme_reset_all_caches();
-}
-
 /**
  * Returns current theme revision number.
  *
@@ -97,6 +55,232 @@ function theme_get_revision() {
     }
 }
 
+/**
+ * Returns current theme sub revision number. This is the revision for
+ * this theme exclusively, not the global theme revision.
+ *
+ * @param string $themename The non-frankenstyle name of the theme
+ * @return int
+ */
+function theme_get_sub_revision_for_theme($themename) {
+    global $CFG;
+
+    if (empty($CFG->themedesignermode)) {
+        $pluginname = "theme_{$themename}";
+        $revision = during_initial_install() ? null : get_config($pluginname, 'themerev');
+
+        if (empty($revision)) {
+            // This only happens during install. It doesn't matter what themerev we use as long as it's positive.
+            return 1;
+        } else {
+            return $revision;
+        }
+    } else {
+        return -1;
+    }
+}
+
+/**
+ * Calculates and returns the next theme revision number.
+ *
+ * @return int
+ */
+function theme_get_next_revision() {
+    global $CFG;
+
+    $next = time();
+    if (isset($CFG->themerev) and $next <= $CFG->themerev and $CFG->themerev - $next < 60*60) {
+        // This resolves problems when reset is requested repeatedly within 1s,
+        // the < 1h condition prevents accidental switching to future dates
+        // because we might not recover from it.
+        $next = $CFG->themerev+1;
+    }
+
+    return $next;
+}
+
+/**
+ * Calculates and returns the next theme revision number.
+ *
+ * @param string $themename The non-frankenstyle name of the theme
+ * @return int
+ */
+function theme_get_next_sub_revision_for_theme($themename) {
+    global $CFG;
+
+    $next = time();
+    $current = theme_get_sub_revision_for_theme($themename);
+    if ($next <= $current and $current - $next < 60 * 60) {
+        // This resolves problems when reset is requested repeatedly within 1s,
+        // the < 1h condition prevents accidental switching to future dates
+        // because we might not recover from it.
+        $next = $current + 1;
+    }
+
+    return $next;
+}
+
+/**
+ * Sets the current theme revision number.
+ *
+ * @param int $revision The new theme revision number
+ */
+function theme_set_revision($revision) {
+    set_config('themerev', $revision);
+}
+
+/**
+ * Sets the current theme revision number for a specific theme.
+ * This does not affect the global themerev value.
+ *
+ * @param string $themename The non-frankenstyle name of the theme
+ * @param int    $revision  The new theme revision number
+ */
+function theme_set_sub_revision_for_theme($themename, $revision) {
+    set_config('themerev', $revision, "theme_{$themename}");
+}
+
+/**
+ * Get the path to a theme config.php file.
+ *
+ * @param string $themename The non-frankenstyle name of the theme to check
+ */
+function theme_get_config_file_path($themename) {
+    global $CFG;
+
+    if (file_exists("{$CFG->dirroot}/theme/{$themename}/config.php")) {
+        return "{$CFG->dirroot}/theme/{$themename}/config.php";
+    } else if (!empty($CFG->themedir) and file_exists("{$CFG->themedir}/{$themename}/config.php")) {
+        return "{$CFG->themedir}/{$themename}/config.php";
+    } else {
+        return null;
+    }
+}
+
+/**
+ * Get the path to the local cached CSS file.
+ *
+ * @param string $themename      The non-frankenstyle theme name.
+ * @param int    $globalrevision The global theme revision.
+ * @param int    $themerevision  The theme specific revision.
+ * @param string $direction      Either 'ltr' or 'rtl' (case sensitive).
+ */
+function theme_get_css_filename($themename, $globalrevision, $themerevision, $direction) {
+    global $CFG;
+
+    $path = "{$CFG->localcachedir}/theme/{$globalrevision}/{$themename}/css";
+    $filename = $direction == 'rtl' ? "all-rtl_{$themerevision}" : "all_{$themerevision}";
+    return "{$path}/{$filename}.css";
+}
+
+/**
+ * Generates and saves the CSS files for the given theme configs.
+ *
+ * @param theme_config[] $themeconfigs An array of theme_config instances.
+ * @param array          $directions   Must be a subset of ['rtl', 'ltr'].
+ * @param bool           $cache        Should the generated files be stored in local cache.
+ * @return array         The built theme content in a multi-dimensional array of name => direction => content
+ */
+function theme_build_css_for_themes($themeconfigs = [], $directions = ['rtl', 'ltr'], $cache = true): array {
+    global $CFG;
+
+    if (empty($themeconfigs)) {
+        return [];
+    }
+
+    require_once("{$CFG->libdir}/csslib.php");
+
+    $themescss = [];
+    $themerev = theme_get_revision();
+    // Make sure the local cache directory exists.
+    make_localcache_directory('theme');
+
+    foreach ($themeconfigs as $themeconfig) {
+        $themecss = [];
+        $oldrevision = theme_get_sub_revision_for_theme($themeconfig->name);
+        $newrevision = theme_get_next_sub_revision_for_theme($themeconfig->name);
+
+        // First generate all the new css.
+        foreach ($directions as $direction) {
+            // Lock it on. Technically we should build all themes for SVG and no SVG - but ie9 is out of support.
+            $themeconfig->force_svg_use(true);
+            $themeconfig->set_rtl_mode(($direction === 'rtl'));
+
+            $themecss[$direction] = $themeconfig->get_css_content();
+            if ($cache) {
+                $themeconfig->set_css_content_cache($themecss[$direction]);
+                $filename = theme_get_css_filename($themeconfig->name, $themerev, $newrevision, $direction);
+                css_store_css($themeconfig, $filename, $themecss[$direction]);
+            }
+        }
+        $themescss[$themeconfig->name] = $themecss;
+
+        if ($cache) {
+            // Only update the theme revision after we've successfully created the
+            // new CSS cache.
+            theme_set_sub_revision_for_theme($themeconfig->name, $newrevision);
+
+            // Now purge old files. We must purge all old files in the local cache
+            // because we've incremented the theme sub revision. This will leave any
+            // files with the old revision inaccessbile so we might as well removed
+            // them from disk.
+            foreach (['ltr', 'rtl'] as $direction) {
+                $oldcss = theme_get_css_filename($themeconfig->name, $themerev, $oldrevision, $direction);
+                if (file_exists($oldcss)) {
+                    unlink($oldcss);
+                }
+            }
+        }
+    }
+
+    return $themescss;
+}
+
+/**
+ * Invalidate all server and client side caches.
+ *
+ * This method deletes the physical directory that is used to cache the theme
+ * files used for serving.
+ * Because it deletes the main theme cache directory all themes are reset by
+ * this function.
+ */
+function theme_reset_all_caches() {
+    global $CFG, $PAGE;
+    require_once("{$CFG->libdir}/filelib.php");
+
+    $next = theme_get_next_revision();
+    theme_set_revision($next);
+
+    if (!empty($CFG->themedesignermode)) {
+        $cache = cache::make_from_params(cache_store::MODE_APPLICATION, 'core', 'themedesigner');
+        $cache->purge();
+    }
+
+    // Purge compiled post processed css.
+    cache::make('core', 'postprocessedcss')->purge();
+
+    // Delete all old theme localcaches.
+    $themecachedirs = glob("{$CFG->localcachedir}/theme/*", GLOB_ONLYDIR);
+    foreach ($themecachedirs as $localcachedir) {
+        fulldelete($localcachedir);
+    }
+
+    if ($PAGE) {
+        $PAGE->reload_theme();
+    }
+}
+
+/**
+ * Enable or disable theme designer mode.
+ *
+ * @param bool $state
+ */
+function theme_set_designer_mod($state) {
+    set_config('themedesignermode', (int)!empty($state));
+    // Reset caches after switching mode so that any designer mode caches get purged too.
+    theme_reset_all_caches();
+}
+
 /**
  * Checks if the given device has a theme defined in config.php.
  *
@@ -190,6 +374,12 @@ class theme_config {
      */
     public $editor_sheets = array();
 
+    /**
+     * @var bool Whether a fallback version of the stylesheet will be used
+     * whilst the final version is generated.
+     */
+    public $usefallback = false;
+
     /**
      * @var array The names of all the javascript files this theme that you would
      * like included from head, in order. Give the names of the files without .js.
@@ -372,7 +562,7 @@ class theme_config {
      * @var stdClass Theme settings stored in config_plugins table.
      * This can not be set in theme config.php
      */
-    public $setting = null;
+    public $settings = null;
 
     /**
      * @var bool If set to true and the theme enables the dock then  blocks will be able
@@ -423,16 +613,10 @@ class theme_config {
      */
     protected $rtlmode = false;
 
-    /**
-     * The LESS file to compile. When set, the theme will attempt to compile the file itself.
-     * @var bool
-     */
-    public $lessfile = false;
-
     /**
      * The SCSS file to compile (without .scss), located in the scss/ folder of the theme.
      * Or a Closure, which receives the theme_config as argument and must
-     * return the SCSS content. This setting takes precedence over self::$lessfile.
+     * return the SCSS content.
      * @var string|Closure
      */
     public $scss = false;
@@ -443,24 +627,12 @@ class theme_config {
      */
     protected $scsscache = null;
 
-    /**
-     * The name of the function to call to get the LESS code to inject.
-     * @var string
-     */
-    public $extralesscallback = null;
-
     /**
      * The name of the function to call to get the SCSS code to inject.
      * @var string
      */
     public $extrascsscallback = null;
 
-    /**
-     * The name of the function to call to get extra LESS variables.
-     * @var string
-     */
-    public $lessvariablescallback = null;
-
     /**
      * The name of the function to call to get SCSS to prepend.
      * @var string
@@ -474,6 +646,18 @@ class theme_config {
      */
     public $blockrendermethod = null;
 
+    /**
+     * Remember the results of icon remapping for the current page.
+     * @var array
+     */
+    public $remapiconcache = [];
+
+    /**
+     * The name of the function to call to get precompiled CSS.
+     * @var string
+     */
+    public $precompiledcsscallback = null;
+
     /**
      * Load the config.php file for a particular theme, and return an instance
      * of this class. (That is, this is a factory method.)
@@ -499,10 +683,15 @@ class theme_config {
             throw new coding_exception('Default theme '.theme_config::DEFAULT_THEME.' not available or broken!');
 
         } else if ($config = theme_config::find_theme_config($CFG->theme, $settings)) {
+            debugging('This page should be using theme ' . $themename .
+                    ' which cannot be initialised. Falling back to the site theme ' . $CFG->theme, DEBUG_NORMAL);
             return new theme_config($config);
 
         } else {
             // bad luck, the requested theme has some problems - admin see details in theme config
+            debugging('This page should be using theme ' . $themename .
+                    ' which cannot be initialised. Nor can the site theme ' . $CFG->theme .
+                    '. Falling back to ' . theme_config::DEFAULT_THEME, DEBUG_NORMAL);
             return new theme_config(theme_config::find_theme_config(theme_config::DEFAULT_THEME, $settings));
         }
     }
@@ -533,20 +722,20 @@ class theme_config {
         $this->name     = $config->name;
         $this->dir      = $config->dir;
 
-        if ($this->name != 'bootstrapbase') {
-            $baseconfig = theme_config::find_theme_config('bootstrapbase', $this->settings);
+        if ($this->name != self::DEFAULT_THEME) {
+            $baseconfig = self::find_theme_config(self::DEFAULT_THEME, $this->settings);
         } else {
             $baseconfig = $config;
         }
 
         $configurable = array(
-            'parents', 'sheets', 'parents_exclude_sheets', 'plugins_exclude_sheets',
+            'parents', 'sheets', 'parents_exclude_sheets', 'plugins_exclude_sheets', 'usefallback',
             'javascripts', 'javascripts_footer', 'parents_exclude_javascripts',
-            'layouts', 'enable_dock', 'enablecourseajax', 'requiredblocks',
-            'rendererfactory', 'csspostprocess', 'editor_sheets', 'rarrow', 'larrow', 'uarrow', 'darrow',
-            'hidefromselector', 'doctype', 'yuicssmodules', 'blockrtlmanipulations',
-            'lessfile', 'extralesscallback', 'lessvariablescallback', 'blockrendermethod',
-            'scss', 'extrascsscallback', 'prescsscallback', 'csstreepostprocessor', 'addblockposition');
+            'layouts', 'enablecourseajax', 'requiredblocks',
+            'rendererfactory', 'csspostprocess', 'editor_sheets', 'editor_scss', 'rarrow', 'larrow', 'uarrow', 'darrow',
+            'hidefromselector', 'doctype', 'yuicssmodules', 'blockrtlmanipulations', 'blockrendermethod',
+            'scss', 'extrascsscallback', 'prescsscallback', 'csstreepostprocessor', 'addblockposition',
+            'iconsystem', 'precompiledcsscallback');
 
         foreach ($config as $key=>$value) {
             if (in_array($key, $configurable)) {
@@ -704,7 +893,15 @@ class theme_config {
         global $CFG;
         $rev = theme_get_revision();
         if ($rev > -1) {
-            $url = new moodle_url("$CFG->httpswwwroot/theme/styles.php");
+            $themesubrevision = theme_get_sub_revision_for_theme($this->name);
+
+            // Provide the sub revision to allow us to invalidate cached theme CSS
+            // on a per theme basis, rather than globally.
+            if ($themesubrevision && $themesubrevision > 0) {
+                $rev .= "_{$themesubrevision}";
+            }
+
+            $url = new moodle_url("/theme/styles.php");
             if (!empty($CFG->slasharguments)) {
                 $url->set_slashargument('/'.$this->name.'/'.$rev.'/editor', 'noparam', true);
             } else {
@@ -712,7 +909,7 @@ class theme_config {
             }
         } else {
             $params = array('theme'=>$this->name, 'type'=>'editor');
-            $url = new moodle_url($CFG->httpswwwroot.'/theme/styles_debug.php', $params);
+            $url = new moodle_url('/theme/styles_debug.php', $params);
         }
         return $url;
     }
@@ -758,6 +955,50 @@ class theme_config {
         return $files;
     }
 
+    /**
+     * Compiles and returns the content of the SCSS to be used in editor content
+     *
+     * @return string Compiled CSS from the editor SCSS
+     */
+    public function editor_scss_to_css() {
+        $css = '';
+        $dir = $this->dir;
+        $filenames = [];
+
+        // Use editor_scss file(s) provided by this theme if set.
+        if (!empty($this->editor_scss)) {
+            $filenames = $this->editor_scss;
+        } else {
+            // If no editor_scss set, move up theme hierarchy until one is found (if at all).
+            // This is so child themes only need to set editor_scss if an override is required.
+            foreach (array_reverse($this->parent_configs) as $parentconfig) {
+                if (!empty($parentconfig->editor_scss)) {
+                    $dir = $parentconfig->dir;
+                    $filenames = $parentconfig->editor_scss;
+
+                    // Config found, stop looking.
+                    break;
+                }
+            }
+        }
+
+        if (!empty($filenames)) {
+            $compiler = new core_scss();
+
+            foreach ($filenames as $filename) {
+                $compiler->set_file("{$dir}/scss/{$filename}.scss");
+
+                try {
+                    $css .= $compiler->to_css();
+                } catch (\Exception $e) {
+                    debugging('Error while compiling editor SCSS: ' . $e->getMessage(), DEBUG_DEVELOPER);
+                }
+            }
+        }
+
+        return $css;
+    }
+
     /**
      * Get the stylesheet URL of this theme.
      *
@@ -776,7 +1017,15 @@ class theme_config {
 
         if ($rev > -1) {
             $filename = right_to_left() ? 'all-rtl' : 'all';
-            $url = new moodle_url("$CFG->httpswwwroot/theme/styles.php");
+            $url = new moodle_url("/theme/styles.php");
+            $themesubrevision = theme_get_sub_revision_for_theme($this->name);
+
+            // Provide the sub revision to allow us to invalidate cached theme CSS
+            // on a per theme basis, rather than globally.
+            if ($themesubrevision && $themesubrevision > 0) {
+                $rev .= "_{$themesubrevision}";
+            }
+
             if (!empty($CFG->slasharguments)) {
                 $slashargs = '';
                 if (!$svg) {
@@ -804,7 +1053,7 @@ class theme_config {
             $urls[] = $url;
 
         } else {
-            $baseurl = new moodle_url($CFG->httpswwwroot.'/theme/styles_debug.php');
+            $baseurl = new moodle_url('/theme/styles_debug.php');
 
             $css = $this->get_css_files(true);
             if (!$svg) {
@@ -829,9 +1078,6 @@ class theme_config {
                 if ($this->get_scss_property()) {
                     // No need to define the type as IE here.
                     $urls[] = new moodle_url($baseurl, array('theme' => $this->name, 'type' => 'scss'));
-                } else if (!empty($this->lessfile)) {
-                    // No need to define the type as IE here.
-                    $urls[] = new moodle_url($baseurl, array('theme' => $this->name, 'type' => 'less'));
                 }
                 $urls[] = new moodle_url($baseurl, array('theme'=>$this->name, 'type'=>'ie', 'subtype'=>'theme'));
 
@@ -848,9 +1094,6 @@ class theme_config {
                     if ($sheet === self::SCSS_KEY) {
                         // This is the theme SCSS file.
                         $urls[] = new moodle_url($baseurl, array('theme' => $this->name, 'type' => 'scss'));
-                    } else if ($sheet === $this->lessfile) {
-                        // This is the theme LESS file.
-                        $urls[] = new moodle_url($baseurl, array('theme' => $this->name, 'type' => 'less'));
                     } else {
                         // Sheet first in order to make long urls easier to read.
                         $urls[] = new moodle_url($baseurl, array('sheet'=>$sheet, 'theme'=>$this->name, 'type'=>'theme'));
@@ -859,6 +1102,8 @@ class theme_config {
             }
         }
 
+        // Allow themes to change the css url to something like theme/mytheme/mycss.php.
+        component_callback('theme_' . $this->name, 'alter_css_urls', [&$urls]);
         return $urls;
     }
 
@@ -881,10 +1126,13 @@ class theme_config {
                 } else {
                     if ($type === 'theme' && $identifier === self::SCSS_KEY) {
                         // We need the content from SCSS because this is the SCSS file from the theme.
-                        $csscontent .= $this->get_css_content_from_scss(false);
-                    } else if ($type === 'theme' && $identifier === $this->lessfile) {
-                        // We need the content from LESS because this is the LESS file from the theme.
-                        $csscontent .= $this->get_css_content_from_less(false);
+                        if ($compiled = $this->get_css_content_from_scss(false)) {
+                            $csscontent .= $compiled;
+                        } else {
+                            // The compiler failed so default back to any precompiled css that might
+                            // exist.
+                            $csscontent .= $this->get_precompiled_css_content();
+                        }
                     } else {
                         $csscontent .= file_get_contents($val) . "\n";
                     }
@@ -896,6 +1144,57 @@ class theme_config {
 
         return $csscontent;
     }
+    /**
+     * Set post processed CSS content cache.
+     *
+     * @param string $csscontent The post processed CSS content.
+     * @return bool True if the content was successfully cached.
+     */
+    public function set_css_content_cache($csscontent) {
+
+        $cache = cache::make('core', 'postprocessedcss');
+        $key = $this->get_css_cache_key();
+
+        return $cache->set($key, $csscontent);
+    }
+
+    /**
+     * Return whether the post processed CSS content has been cached.
+     *
+     * @return bool Whether the post-processed CSS is available in the cache.
+     */
+    public function has_css_cached_content() {
+
+        $key = $this->get_css_cache_key();
+        $cache = cache::make('core', 'postprocessedcss');
+
+        return $cache->has($key);
+    }
+
+    /**
+     * Return cached post processed CSS content.
+     *
+     * @return bool|string The cached css content or false if not found.
+     */
+    public function get_css_cached_content() {
+
+        $key = $this->get_css_cache_key();
+        $cache = cache::make('core', 'postprocessedcss');
+
+        return $cache->get($key);
+    }
+
+    /**
+     * Generate the css content cache key.
+     *
+     * @return string The post processed css cache key.
+     */
+    public function get_css_cache_key() {
+        $nosvg = (!$this->use_svg_icons()) ? 'nosvg_' : '';
+        $rtlmode = ($this->rtlmode == true) ? 'rtl' : 'ltr';
+
+        return $nosvg . $this->name . '_' . $rtlmode;
+    }
 
     /**
      * Get the theme designer css markup,
@@ -909,7 +1208,6 @@ class theme_config {
      * @return string CSS markup
      */
     public function get_css_content_debug($type, $subtype, $sheet) {
-
         if ($type === 'scss') {
             // The SCSS file of the theme is requested.
             $csscontent = $this->get_css_content_from_scss(true);
@@ -917,13 +1215,6 @@ class theme_config {
                 return $this->post_process($csscontent);
             }
             return '';
-        } else if ($type === 'less') {
-            // The LESS file of the theme is requested.
-            $csscontent = $this->get_css_content_from_less(true);
-            if ($csscontent !== false) {
-                return $this->post_process($csscontent);
-            }
-            return '';
         }
 
         $cssfiles = array();
@@ -946,9 +1237,9 @@ class theme_config {
             } else if ($subtype === 'theme') {
                 $cssfiles = $css['theme'];
                 foreach ($cssfiles as $key => $value) {
-                    if (in_array($key, [$this->lessfile, self::SCSS_KEY])) {
-                        // Remove the LESS/SCSS file from the theme CSS files.
-                        // The LESS/SCSS files use the type 'less' or 'scss', not 'ie'.
+                    if (in_array($key, [self::SCSS_KEY])) {
+                        // Remove the SCSS file from the theme CSS files.
+                        // The SCSS files use the type 'scss', not 'ie'.
                         unset($cssfiles[$key]);
                     }
                 }
@@ -990,13 +1281,22 @@ class theme_config {
      * @return string CSS markup
      */
     public function get_css_content_editor() {
-        // Do not bother to optimise anything here, just very basic stuff.
-        $cssfiles = $this->editor_css_files();
         $css = '';
+        $cssfiles = $this->editor_css_files();
+
+        // If editor has static CSS, include it.
         foreach ($cssfiles as $file) {
             $css .= file_get_contents($file)."\n";
         }
-        return $this->post_process($css);
+
+        // If editor has SCSS, compile and include it.
+        if (($convertedscss = $this->editor_scss_to_css())) {
+            $css .= $convertedscss;
+        }
+
+        $output = $this->post_process($css);
+
+        return $output;
     }
 
     /**
@@ -1087,17 +1387,11 @@ class theme_config {
         }
 
 
-        // Current theme sheets and less file.
-        // We first add the SCSS, or LESS file because we want the CSS ones to
-        // be included after the SCSS/LESS code. However, if both the LESS file
-        // and a CSS file share the same name, the CSS file is ignored.
+        // Current theme sheets.
+        // We first add the SCSS file because we want the CSS ones to
+        // be included after the SCSS code.
         if ($this->get_scss_property()) {
             $cssfiles['theme'][self::SCSS_KEY] = true;
-        } else if (!empty($this->lessfile)) {
-            $sheetfile = "{$this->dir}/less/{$this->lessfile}.less";
-            if (is_readable($sheetfile)) {
-                $cssfiles['theme'][$this->lessfile] = $sheetfile;
-            }
         }
         if (is_array($this->sheets)) {
             foreach ($this->sheets as $sheet) {
@@ -1116,71 +1410,6 @@ class theme_config {
         return $cssfiles;
     }
 
-    /**
-     * Return the CSS content generated from LESS the file.
-     *
-     * @param bool $themedesigner True if theme designer is enabled.
-     * @return bool|string Return false when the compilation failed. Else the compiled string.
-     */
-    protected function get_css_content_from_less($themedesigner) {
-        global $CFG;
-
-        $lessfile = $this->lessfile;
-        if (!$lessfile || !is_readable($this->dir . '/less/' . $lessfile . '.less')) {
-            throw new coding_exception('The theme did not define a LESS file, or it is not readable.');
-        }
-
-        // We might need more memory to do this, so let's play safe.
-        raise_memory_limit(MEMORY_EXTRA);
-
-        // Files list.
-        $files = $this->get_css_files($themedesigner);
-
-        // Get the LESS file path.
-        $themelessfile = $files['theme'][$lessfile];
-
-        // Setup compiler options.
-        $options = array(
-            // We need to set the import directory to where $lessfile is.
-            'import_dirs' => array(dirname($themelessfile) => '/'),
-            // Always disable default caching.
-            'cache_method' => false,
-            // Disable the relative URLs, we have post_process() to handle that.
-            'relativeUrls' => false,
-        );
-
-        if ($themedesigner) {
-            // Add the sourceMap inline to ensure that it is atomically generated.
-            $options['sourceMap'] = true;
-            $options['sourceMapBasepath'] = $CFG->dirroot;
-            $options['sourceMapRootpath'] = $CFG->wwwroot;
-        }
-
-        // Instantiate the compiler.
-        $compiler = new core_lessc($options);
-
-        try {
-            $compiler->parse_file_content($themelessfile);
-
-            // Get the callbacks.
-            $compiler->parse($this->get_extra_less_code());
-            $compiler->ModifyVars($this->get_less_variables());
-
-            // Compile the CSS.
-            $compiled = $compiler->getCss();
-
-        } catch (Less_Exception_Parser $e) {
-            $compiled = false;
-            debugging('Error while compiling LESS ' . $lessfile . ' file: ' . $e->getMessage(), DEBUG_DEVELOPER);
-        }
-
-        // Try to save memory.
-        $compiler = null;
-        unset($compiler);
-
-        return $compiled;
-    }
-
     /**
      * Return the CSS content generated from the SCSS file.
      *
@@ -1195,11 +1424,23 @@ class theme_config {
             throw new coding_exception('The theme did not define a SCSS file, or it is not readable.');
         }
 
-        // We might need more memory to do this, so let's play safe.
+        // We might need more memory/time to do this, so let's play safe.
         raise_memory_limit(MEMORY_EXTRA);
+        core_php_time_limit::raise(300);
 
+        // TODO: MDL-62757 When changing anything in this method please do not forget to check
+        // if the validate() method in class admin_setting_configthemepreset needs updating too.
+        $cacheoptions = '';
+        if ($themedesigner) {
+            $scsscachedir = $CFG->localcachedir . '/scsscache/';
+            $cacheoptions = array(
+                  'cacheDir' => $scsscachedir,
+                  'prefix' => 'scssphp_',
+                  'forceRefresh' => false,
+            );
+        }
         // Set-up the compiler.
-        $compiler = new core_scss();
+        $compiler = new core_scss($cacheoptions);
         $compiler->prepend_raw_scss($this->get_pre_scss_code());
         if (is_string($scss)) {
             $compiler->set_file($scss);
@@ -1213,7 +1454,7 @@ class theme_config {
             // Compile!
             $compiled = $compiler->to_css();
 
-        } catch (\Leafo\ScssPhp\Exception $e) {
+        } catch (\Exception $e) {
             $compiled = false;
             debugging('Error while compiling SCSS: ' . $e->getMessage(), DEBUG_DEVELOPER);
         }
@@ -1226,68 +1467,43 @@ class theme_config {
     }
 
     /**
-     * Return extra LESS variables to use when compiling.
+     * Return the precompiled CSS if the precompiledcsscallback exists.
      *
-     * @return array Where keys are the variable names (omitting the @), and the values are the value.
+     * @return string Return compiled css.
      */
-    protected function get_less_variables() {
-        $variables = array();
+    public function get_precompiled_css_content() {
+        $configs = array_reverse($this->parent_configs) + [$this];
+        $css = '';
 
-        // Getting all the candidate functions.
-        $candidates = array();
-        foreach ($this->parent_configs as $parent_config) {
-            if (!isset($parent_config->lessvariablescallback)) {
-                continue;
-            }
-            $candidates[] = $parent_config->lessvariablescallback;
-        }
-        $candidates[] = $this->lessvariablescallback;
-
-        // Calling the functions.
-        foreach ($candidates as $function) {
-            if (function_exists($function)) {
-                $vars = $function($this);
-                if (!is_array($vars)) {
-                    debugging('Callback ' . $function . ' did not return an array() as expected', DEBUG_DEVELOPER);
-                    continue;
+        foreach ($configs as $config) {
+            if (isset($config->precompiledcsscallback)) {
+                $function = $config->precompiledcsscallback;
+                if (function_exists($function)) {
+                    $css .= $function($this);
                 }
-                $variables = array_merge($variables, $vars);
             }
         }
-
-        return $variables;
+        return $css;
     }
 
     /**
-     * Return extra LESS code to add when compiling.
+     * Get the icon system to use.
      *
-     * This is intended to be used by themes to inject some LESS code
-     * before it gets compiled. If you want to inject variables you
-     * should use {@link self::get_less_variables()}.
-     *
-     * @return string The LESS code to inject.
+     * @return string
      */
-    protected function get_extra_less_code() {
-        $content = '';
+    public function get_icon_system() {
 
         // Getting all the candidate functions.
-        $candidates = array();
+        $system = false;
+        if (isset($this->iconsystem) && \core\output\icon_system::is_valid_system($this->iconsystem)) {
+            return $this->iconsystem;
+        }
         foreach ($this->parent_configs as $parent_config) {
-            if (!isset($parent_config->extralesscallback)) {
-                continue;
-            }
-            $candidates[] = $parent_config->extralesscallback;
-        }
-        $candidates[] = $this->extralesscallback;
-
-        // Calling the functions.
-        foreach ($candidates as $function) {
-            if (function_exists($function)) {
-                $content .= "\n/** Extra LESS from $function **/\n" . $function($this) . "\n";
+            if (isset($parent_config->iconsystem) && \core\output\icon_system::is_valid_system($parent_config->iconsystem)) {
+                return $parent_config->iconsystem;
             }
         }
-
-        return $content;
+        return \core\output\icon_system::STANDARD;
     }
 
     /**
@@ -1299,7 +1515,7 @@ class theme_config {
      *
      * @return string The SCSS code to inject.
      */
-    protected function get_extra_scss_code() {
+    public function get_extra_scss_code() {
         $content = '';
 
         // Getting all the candidate functions.
@@ -1329,7 +1545,7 @@ class theme_config {
      *
      * @return string The SCSS code to inject.
      */
-    protected function get_pre_scss_code() {
+    public function get_pre_scss_code() {
         $content = '';
 
         // Getting all the candidate functions.
@@ -1415,11 +1631,11 @@ class theme_config {
         }
 
         if (!empty($CFG->slasharguments) and $rev > 0) {
-            $url = new moodle_url("$CFG->httpswwwroot/theme/javascript.php");
+            $url = new moodle_url("/theme/javascript.php");
             $url->set_slashargument('/'.$this->name.'/'.$rev.'/'.$params['type'], 'noparam', true);
             return $url;
         } else {
-            return new moodle_url($CFG->httpswwwroot.'/theme/javascript.php', $params);
+            return new moodle_url('/theme/javascript.php', $params);
         }
     }
 
@@ -1538,7 +1754,7 @@ class theme_config {
                 $replaced[$match[0]] = true;
                 $imagename = $match[2];
                 $component = rtrim($match[1], '|');
-                $imageurl = $this->pix_url($imagename, $component)->out(false);
+                $imageurl = $this->image_url($imagename, $component)->out(false);
                  // we do not need full url because the image.php is always in the same dir
                 $imageurl = preg_replace('|^http.?://[^/]+|', '', $imageurl);
                 $css = str_replace($match[0], $imageurl, $css);
@@ -1574,8 +1790,9 @@ class theme_config {
         $needsparsing = !empty($treeprocessor) || !empty($this->rtlmode);
         if ($needsparsing) {
 
-            // We might need more memory to do this, so let's play safe.
+            // We might need more memory/time to do this, so let's play safe.
             raise_memory_limit(MEMORY_EXTRA);
+            core_php_time_limit::raise(300);
 
             $parser = new core_cssparser($css);
             $csstree = $parser->parse();
@@ -1608,13 +1825,30 @@ class theme_config {
     }
 
     /**
-     * Return the URL for an image
+     * Return the direct URL for an image from the pix folder.
      *
+     * Use this function sparingly and never for icons. For icons use pix_icon or the pix helper in a mustache template.
+     *
+     * @deprecated since Moodle 3.3
      * @param string $imagename the name of the icon.
      * @param string $component specification of one plugin like in get_string()
      * @return moodle_url
      */
     public function pix_url($imagename, $component) {
+        debugging('pix_url is deprecated. Use image_url for images and pix_icon for icons.', DEBUG_DEVELOPER);
+        return $this->image_url($imagename, $component);
+    }
+
+    /**
+     * Return the direct URL for an image from the pix folder.
+     *
+     * Use this function sparingly and never for icons. For icons use pix_icon or the pix helper in a mustache template.
+     *
+     * @param string $imagename the name of the icon.
+     * @param string $component specification of one plugin like in get_string()
+     * @return moodle_url
+     */
+    public function image_url($imagename, $component) {
         global $CFG;
 
         $params = array('theme'=>$this->name);
@@ -1633,7 +1867,7 @@ class theme_config {
 
         $params['image'] = $imagename;
 
-        $url = new moodle_url("$CFG->httpswwwroot/theme/image.php");
+        $url = new moodle_url("/theme/image.php");
         if (!empty($CFG->slasharguments) and $rev > 0) {
             $path = '/'.$params['theme'].'/'.$params['component'].'/'.$params['rev'].'/'.$params['image'];
             if (!$svg) {
@@ -1679,7 +1913,7 @@ class theme_config {
 
         $params['font'] = $font;
 
-        $url = new moodle_url("$CFG->httpswwwroot/theme/font.php");
+        $url = new moodle_url("/theme/font.php");
         if (!empty($CFG->slasharguments) and $rev > 0) {
             $path = '/'.$params['theme'].'/'.$params['component'].'/'.$params['rev'].'/'.$params['font'];
             $url->set_slashargument($path, 'noparam', true);
@@ -1775,7 +2009,8 @@ class theme_config {
      *
      * @param string $image name of image, may contain relative path
      * @param string $component
-     * @param bool $svg If set to true SVG images will also be looked for.
+     * @param bool $svg|null Should SVG images also be looked for? If null, resorts to $CFG->svgicons if that is set; falls back to
+     * auto-detection of browser support otherwise
      * @return string full file path
      */
     public function resolve_image_location($image, $component, $svg = false) {
@@ -1947,6 +2182,15 @@ class theme_config {
         $this->rtlmode = $inrtl;
     }
 
+    /**
+     * Whether the theme is being served in RTL mode.
+     *
+     * @return bool True when in RTL mode.
+     */
+    public function get_rtl_mode() {
+        return $this->rtlmode;
+    }
+
     /**
      * Checks if file with any image extension exists.
      *
@@ -2174,8 +2418,8 @@ class theme_config {
             }
         }
 
-        // Last resort, try the bootstrapbase theme for names
-        return get_string('region-' . $region, 'theme_bootstrapbase');
+        // Last resort, try the boost theme for names
+        return get_string('region-' . $region, 'theme_boost');
     }
 
     /**
@@ -2242,6 +2486,7 @@ class theme_config {
         }
         return null;
     }
+
 }
 
 /**
