@@ -99,6 +99,15 @@ Y.extend(DRAGDROP, Y.Base, {
      */
     lastdroptarget: null,
 
+    /**
+     * Should the direction of a keyboard drag and drop item be detected.
+     *
+     * @property detectkeyboarddirection
+     * @type Boolean
+     * @default false
+     */
+    detectkeyboarddirection: false,
+
     /**
      * Listeners.
      *
@@ -418,7 +427,7 @@ Y.extend(DRAGDROP, Y.Base, {
             var className = node.getAttribute("class").split(' ').join(', .');
 
             if (node.drop && node.drop.inGroup(this.groups) && node.drop.get('node') !== dragcontainer &&
-                    node.next(className) !== dragcontainer) {
+                    !(node.next(className) === dragcontainer && !this.detectkeyboarddirection)) {
                 // This is a drag and drop target with the same class as the grabbed node.
                 validdrop = true;
             } else {
@@ -426,7 +435,7 @@ Y.extend(DRAGDROP, Y.Base, {
                 var i, j;
                 for (i = 0; i < elementgroups.length; i++) {
                     for (j = 0; j < this.groups.length; j++) {
-                        if (elementgroups[i] === this.groups[j] && !(node == dragcontainer ||
+                        if (elementgroups[i] === this.groups[j] && !node.ancestor('.yui3-dd-proxy') && !(node == dragcontainer ||
                             node.next(className) === dragcontainer || node.get('children').item(0) == dragcontainer)) {
                                 // This is a parent node of the grabbed node (used for dropping in empty sections).
                                 validdrop = true;
@@ -566,6 +575,16 @@ Y.extend(DRAGDROP, Y.Base, {
         M.core.dragdrop.dropui.hide();
         // Cancel the event.
         e.preventDefault();
+        // Detect the direction of travel.
+        if (this.detectkeyboarddirection && dragcontainer.getY() > droptarget.getY()) {
+            // We can detect the keyboard direction and it is going up.
+            this.absgoingup = true;
+            this.goingup = true;
+        } else {
+            // The default behaviour is to treat everything as moving down.
+            this.absgoingup = false;
+            this.goingup = false;
+        }
         // Convert to drag drop events.
         var dragevent = new this.simulated_drag_drop_event(dragcontainer, dragcontainer);
         var dropevent = new this.simulated_drag_drop_event(dragcontainer, droptarget);
@@ -574,10 +593,7 @@ Y.extend(DRAGDROP, Y.Base, {
         this.global_drop_over(dropevent);
 
         if (droptarget.hasClass(this.parentnodeclass) && droptarget.contains(dragcontainer)) {
-            // The global_drop_over function does not handle the case where an item was moved up, without the
-            // 'goingup' variable being set, as is the case wih keyboard drag/drop. We must detect this case and
-            // apply it after the drop_over, but before the drop_hit event in order for it to be moved to the
-            // correct location.
+            // Handle the case where an item is dropped into a container (for example an activity into a new section).
             droptarget.prepend(dragcontainer);
         }
 
